// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_layout/src/presentation/layouts/layout.dart';

abstract class TopBarLayout<T extends TopBarComponent> extends Layout {
  const TopBarLayout({
    required this.body,
    this.custom,
    this.height = 60,
    super.key,
  });
  final Widget body;

  final T? Function(T?)? custom;
  final double height;

  T? child(BuildContext context);

  @override
  Widget build(BuildContext context) => Scaffold(
        appBar: PreferredSize(
          preferredSize: Size.fromHeight(height),
          child: custom?.call(child(context)) ?? const SizedBox.shrink(),
        ),
        body: body,
      );
}

class TopAppBarLayout extends TopBarLayout<TopAppBarComponent> {
  const TopAppBarLayout({
    required super.body,
    super.custom,
    super.height,
    super.key,
  });

  @override
  TopAppBarComponent? child(BuildContext context) => context.components.appBar;
}

class TopNavigationBarLayout extends TopBarLayout<TopNavigationBarComponent> {
  const TopNavigationBarLayout({
    required super.body,
    super.custom,
    super.height,
    super.key,
  });

  @override
  TopNavigationBarComponent? child(BuildContext context) =>
      context.components.topNavigationBarComponent;
}
