// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_layout/src/presentation/layouts/layout.dart';

class FrameLayout extends Layout {
  const FrameLayout({
    required this.body,
    this.customAppBar,
    this.customBottomNavBar,
    this.height = 60,
    super.key,
  });

  final TopAppBarComponent? Function(TopAppBarComponent?)? customAppBar;
  final BottomNavigationBarComponent? Function(BottomNavigationBarComponent?)?
      customBottomNavBar;
  final Widget body;
  final double height;

  @override
  Widget build(BuildContext context) => Scaffold(
        appBar: PreferredSize(
          preferredSize: Size.fromHeight(height),
          child: customAppBar?.call(context.components.appBar) ??
              const SizedBox.shrink(),
        ),
        body: body,
        bottomNavigationBar:
            customBottomNavBar?.call(context.components.bottomNavigationBar),
      );
}
